@@ -1,6 +1,7 @@
 // Predefined symbols and macros -*- C++ -*-
 
-// Copyright (C) 1997, 1998, 1999, 2000, 2001 Free Software Foundation, Inc.
+// Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003
+// Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -34,10 +35,9 @@
 #include <bits/os_defines.h>
 
 // The current version of the C++ library in compressed ISO date format.
-#define __GLIBCPP__ 20030422
+#define __GLIBCPP__ 20030804
 
-// This is necessary until GCC supports separate template
-// compilation.  
+// This is necessary until GCC supports separate template compilation.
 #define _GLIBCPP_NO_TEMPLATE_EXPORT 1
 
 // This is a hack around not having either pre-compiled headers or
@@ -49,6 +49,16 @@
 // by the compiler, but instead instantiated into the library binary.
 #define _GLIBCPP_FULLY_COMPLIANT_HEADERS 1
 
+// Allow use of the GNU syntax extension, "extern template." This
+// extension is fully documented in the g++ manual, but in a nutshell,
+// it inhibits all implicit instantiations and is used throughout the
+// library to avoid multiple weak definitions for required types that
+// are already explicitly instantiated in the library binary. This
+// substantially reduces the binary size of resulting executables.
+#ifndef _GLIBCPP_EXTERN_TEMPLATE
+#define _GLIBCPP_EXTERN_TEMPLATE 1
+#endif
+
 // To enable older, ARM-style iostreams and other anachronisms use this.
 //#define _GLIBCPP_DEPRECATED 1
 
@@ -77,6 +87,13 @@
 #error __USE_MALLOC should never be defined.  Read the release notes.
 #endif
 
+// Create a boolean flag to be used to determine if --fast-math is set.
+#ifdef __FAST_MATH__
+#define _GLIBCPP_FAST_MATH 1
+#else
+#define _GLIBCPP_FAST_MATH 0
+#endif
+
 // The remainder of the prewritten config is mostly automatic; all the
 // user hooks are listed above.
 
@@ -122,6 +139,18 @@
 // Define if gthr-default.h exists (meaning that threading support is enabled).
 #define _GLIBCPP_HAVE_GTHR_DEFAULT 1
 
+// Define if drand48 exists.
+#define _GLIBCPP_HAVE_DRAND48 1
+
+// Define if getpagesize exists.
+#define _GLIBCPP_HAVE_GETPAGESIZE 1
+
+// Define if setenv exists.
+#define _GLIBCPP_HAVE_SETENV 1
+
+// Define if sigsetjmp exists.
+#define _GLIBCPP_HAVE_SIGSETJMP 1
+
 // Define if mbstate_t exists in wchar.h.
 #define _GLIBCPP_HAVE_MBSTATE_T 1
 
@@ -150,13 +179,13 @@
 #define _GLIBCPP_HAVE___BUILTIN_LABS 1
 
 // Define if the compiler/host combination has __builtin_cos
-/* #undef _GLIBCPP_HAVE___BUILTIN_COS */
+#define _GLIBCPP_HAVE___BUILTIN_COS 1
 
 // Define if the compiler/host combination has __builtin_cosf
-/* #undef _GLIBCPP_HAVE___BUILTIN_COSF */
+#define _GLIBCPP_HAVE___BUILTIN_COSF 1
 
 // Define if the compiler/host combination has __builtin_cosl
-/* #undef _GLIBCPP_HAVE___BUILTIN_COSL */
+#define _GLIBCPP_HAVE___BUILTIN_COSL 1
 
 // Define if the compiler/host combination has __builtin_fabs
 #define _GLIBCPP_HAVE___BUILTIN_FABS 1
@@ -168,13 +197,13 @@
 #define _GLIBCPP_HAVE___BUILTIN_FABSL 1
 
 // Define if the compiler/host combination has __builtin_sin
-/* #undef _GLIBCPP_HAVE___BUILTIN_SIN */
+#define _GLIBCPP_HAVE___BUILTIN_SIN 1
 
 // Define if the compiler/host combination has __builtin_sinf
-/* #undef _GLIBCPP_HAVE___BUILTIN_SINF */
+#define _GLIBCPP_HAVE___BUILTIN_SINF 1
 
 // Define if the compiler/host combination has __builtin_sinl
-/* #undef _GLIBCPP_HAVE___BUILTIN_SINL */
+#define _GLIBCPP_HAVE___BUILTIN_SINL 1
 
 // Define if the compiler/host combination has __builtin_sqrt
 /* #undef _GLIBCPP_HAVE___BUILTIN_SQRT */
@@ -185,6 +214,15 @@
 // Define if the compiler/host combination has __builtin_sqrtl
 /* #undef _GLIBCPP_HAVE___BUILTIN_SQRTL */
 
+// Define if poll is available in <poll.h>.
+#define _GLIBCPP_HAVE_POLL 1
+
+// Define if S_ISREG (Posix) is available in <sys/stat.h>.
+#define _GLIBCPP_HAVE_S_ISREG 1
+
+// Define if S_IFREG is available in <sys/stat.h>.
+/* #undef _GLIBCPP_HAVE_S_IFREG */
+
 // Define if LC_MESSAGES is available in <locale.h>.
 #define _GLIBCPP_HAVE_LC_MESSAGES 1
 
@@ -815,6 +853,12 @@
 /* Define if you have the <string.h> header file.  */
 #define _GLIBCPP_HAVE_STRING_H 1
 
+/* Define if you have the <sys/filio.h> header file.  */
+/* #undef _GLIBCPP_HAVE_SYS_FILIO_H */
+
+/* Define if you have the <sys/ioctl.h> header file.  */
+#define _GLIBCPP_HAVE_SYS_IOCTL_H 1
+
 /* Define if you have the <sys/isa_defs.h> header file.  */
 /* #undef _GLIBCPP_HAVE_SYS_ISA_DEFS_H */
 
@@ -825,7 +869,10 @@
 #define _GLIBCPP_HAVE_SYS_RESOURCE_H 1
 
 /* Define if you have the <sys/stat.h> header file.  */
-#define _GLIBCPP_HAVE_SYS_STAT_H 1
+/* #undef _GLIBCPP_HAVE_SYS_STAT_H */
+
+/* Define if you have the <sys/time.h> header file.  */
+#define _GLIBCPP_HAVE_SYS_TIME_H 1
 
 /* Define if you have the <sys/types.h> header file.  */
 #define _GLIBCPP_HAVE_SYS_TYPES_H 1
@@ -846,7 +893,7 @@
 #define _GLIBCPP_PACKAGE "libstdc++"
 
 /* Version number of package */
-#define _GLIBCPP_VERSION "3.2.3"
+#define _GLIBCPP_VERSION "3.3.1"
 
 /* Define if the compiler is configured for setjmp/longjmp exceptions. */
 /* #undef _GLIBCPP_SJLJ_EXCEPTIONS */
